Bitrate

Struct Bitrate 

pub struct Bitrate(/* private fields */);
A data rate expressed as bits per second(bps).

Internally the value is tracked as a floating point number for accuracy in the presence of repeated calculations that can yield decimal values.

Implementations

Source

impl Bitrate

pub const ZERO: Bitrate

A bitrate of zero bit/s.

pub const MAX: Bitrate

The maximum bitrate that can be represented.

pub const INFINITY: Bitrate

Positive infinity, useful as an invalid value with comparison semantics

pub const NEG_INFINITY: Bitrate

Negative infinity, useful as an invalid value with comparison semantics

pub const fn bps(bps: u64) -> Bitrate

Create a bitrate of some bit per second(bps).

pub const fn kbps(kbps: u64) -> Bitrate

Create a bitrate of some Kilobits per second(kbps).

pub const fn mbps(mbps: u64) -> Bitrate

Create a bitrate of some Megabits per second(mbps).

pub const fn gbps(gbps: u64) -> Bitrate

Create a bitrate of some Gigabits per second(gbps).

pub fn as_f64(&self) -> f64

The number of bits per second as f64.

pub fn as_u64(&self) -> u64

The number of bits per second rounded upwards as u64.

pub fn clamp(&self, min: Bitrate, max: Bitrate) -> Bitrate

Clamp the value between a min and a max.

pub fn min(&self, other: Bitrate) -> Bitrate

Return the minimum bitrate between self and other.

pub fn max(&self, other: Bitrate) -> Bitrate

Return the maximum bitrate between self and other.

pub fn is_valid(&self) -> bool

Whether this bitrate is valid

pub fn as_valid(&self) -> Option<Bitrate>

Turn self into Option<Bitrate> based on its validity

pub fn is_zero(&self) -> bool

Whether this value is zero